@@ -1,7 +1,7 @@
 from typing import (
-    Callable,
     List,
     Optional,
+    Tuple,
 )
 from typing_extensions import (
     Final,
@@ -18,22 +18,32 @@ from .utility import (
     toInt,
 )
 
+
+class SpiStub:
+    def xfer2(self, data: List[int]) -> List[int]:
+        pass
+
+
 class SpinDevice:
     """Class providing access to a single SPIN device"""
 
     def __init__(
-            self, position: int,
-            total_devices: int,
-            spi_transfer: Callable[[List[int]], List[int]],
-        ):
+            self, position: int, busy_pin: int,
+            total_devices: int, spi: SpiStub,
+            chip_select_pin: Optional[int] = None):
         """
         :position: Position in chain, where 0 is the last device in chain
+        :chip_select_pin: Chip select pin,
+        if different from hardware SPI CS pin
+        :busy_pin: Pin to read busy status from
         :total_devices: Total number of devices in chain
         :spi: SPI object used for serial communication
         """
         self._position: Final           = position
+        self._chip_select_pin: Final    = chip_select_pin
+        self._busy_pin: Final           = busy_pin
         self._total_devices: Final      = total_devices
-        self._spi_transfer: Final       = spi_transfer
+        self._spi: Final                = spi
 
         self._direction                 = Constant.DirForward
 
@@ -43,13 +53,15 @@ class SpinDevice:
         :data: A single byte representing a command or value
         :return: Returns response byte
         """
-        assert data >= 0
-        assert data <= 0xFF
+        assert(data >= 0)
+        assert(data <= 0xFF)
 
-        buffer = [Command.Nop] * self._total_devices
+        buffer = [0] * self._total_devices
         buffer[self._position] = data
 
-        response = self._spi_transfer(buffer)
+        # TODO: CS LOW
+        response = self._spi.xfer2(buffer)
+        # TODO: CS HIGH
 
         return response[self._position]
 
@@ -78,8 +90,8 @@ class SpinDevice:
         :payload_size: Payload size in bytes
         :return: Response bytes as int
         """
-        assert (payload is None) == (payload_size is None), \
-            'payload and payload_size must be either both None, xor present'
+        # payload and payload_size must be either both present, or both absent
+        assert((payload is None) != (payload_size is None))
 
         response = self._write(command)
 
@@ -120,8 +132,8 @@ class SpinDevice:
         :steps: Number of (micro)steps to take
 
         """
-        assert steps >= 0
-        assert steps <= Constant.MaxSteps
+        assert(steps >= 0)
+        assert(steps <= Constant.MaxSteps)
 
         PayloadSize = Command.getPayloadSize(Command.Move)
 
@@ -134,8 +146,8 @@ class SpinDevice:
         0.015 step/s resolution
 
         """
-        assert steps_per_second >= 0
-        assert steps_per_second <= Constant.MaxStepsPerSecond
+        assert(steps_per_second >= 0)
+        assert(steps_per_second <= Constant.MaxStepsPerSecond)
 
         speed = int(steps_per_second * Constant.SpsToSpeed)
         PayloadSize = Command.getPayloadSize(Command.Run)
@@ -148,8 +160,8 @@ class SpinDevice:
         :direction: Direction as declared in Constant
 
         """
-        assert direction >= 0
-        assert direction < Constant.DirMax
+        assert(direction >= 0)
+        assert(direction < Constant.DirMax)
 
         self._direction = direction
 
@@ -183,9 +195,7 @@ class SpinDevice:
         :returns: 2 bytes status as an int
 
         """
-        self._writeCommand(Command.StatusGet)
-
-        return self._writeMultiple([Command.Nop] * 2)
+        return self._writeCommand(Command.Status)
 
     def isBusy(self) -> bool:
         """Checks busy status of the device
